@@ -1,11 +1,12 @@
 """Import all the classes."""
 
 from .tracemoe import TraceMoe
+from .async_trace import Async_Trace
 from .errors import *
 
 __author__ = ["DragSama"]
-__version__ = 0.6
+__version__ = 0.8
 
 if __name__ == '__main__':
   from pprint import pprint
-  pprint(__author__, __version__, TraceMoe)
+  pprint(__author__, __version__, TraceMoe, Async_Trace)
